แพ็คเกจ python สำหรับเล่าประวัติขอฝพี่ตี๋ ตั๊กอุบล
==================================================

Link: https://www.youtube.com/watch?v=JsfIcV_4eik

PyPi:

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install theethugubon

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from theethugubon import TheeThugUBon

   thee = TheeThugUbon() #ประกาศชื่อclass
   thee.show_name() #แสดงชื่อพี่ตี๋
   thee.about() #เล่าประวัติพี่ตี๋
   thee.show_art() #โชว์วาดภาพพี่ตี๋

พัฒนาโดย: Annerez FB:

YouTube:
